This dataset contains a matrix and a data frame: genus-level microbiome profiles and corresponding sample metadata from an oral microbiome perturbation study. 28 participants' oral microbiomes were measured before, 15 minutes after, and 2 hours after perturbation with either a water control, antiseptic mouthwash, alchohol-free mouthwash, or soda. The dataset is used in examples and vignettes throughout the package.
oral_mouthwash_dataA named list of one matrix and a dataframe:
countsA matrix with read counts with 116 rows and 81 columns)
metadataA data frame with 81 rows and 38 columns containing sample-level covariates.
The counts matrix has one row per sample and one column per genus.
The metadata data frame has one row per sample with metadata, critically the participant ID, flow cytometry average (and replicate) cells, time_c (time points), and treat (the perturbations )